Installation — Django Stories v0.5 documentation

Django Stories v0.5 documentation

# Installation

- Table of Contents
- index
  modules
  next
  previous

# Installation

### * Add javascript for advanced and simple modes of editing ### Maybe not

- Move authors to own section and below content.
- Auto-add the user if it is a new story
- Remove pluggable markups from settings and models
- Super Users can see everything!
- new templates for reversion to make it not editable, and show changes (optionally?)

Dependencies:

> diff_match_patch (included in lib)

Integration with django-tinymce

Integration with django-reversion

Integration with django-categories